@@ -28,7 +28,11 @@ class VMAlreadyExists(VirtualBMCError):
 
 
 class VMNotFound(VirtualBMCError):
-    message = "No VN with matching name %(vm)s was found"
+    message = "No VM with matching name %(vm)s was found"
+
+
+class VMNotFoundByUUID(VirtualBMCError):
+    message = "No VM with matching UUID %(uuid)s was found"
 
 
 class VIServerConnectionOpenError(VirtualBMCError):
