@@ -54,6 +54,14 @@ SET_BOOT_DEVICES_MAP = {
 }
 
 
+def _get_vm_object(conn, vm_obj):
+    """Simple wrapper to chose lookup method"""
+    if vm_obj.vm_uuid:
+        LOG.debug('UUID lookup method called for vm uuid %s' % vm_obj.vm_uuid)
+        return utils.get_viserver_vm_by_uuid(conn, vm_obj.vm_uuid)
+    return utils.get_viserver_vm(conn, vm_obj.vm_name)
+
+
 def sessionless_data(self, data, sockaddr):
     """Examines unsolocited packet and decides appropriate action.
 
@@ -177,6 +185,7 @@ class VirtualBMC(bmc.Bmc):
         address,
         fakemac,
         vm_name,
+        vm_uuid,
         viserver,
         viserver_username=None,
         viserver_password=None,
@@ -186,6 +195,7 @@ class VirtualBMC(bmc.Bmc):
             {username: password}, port=port, address=address
         )
         self.vm_name = vm_name
+        self.vm_uuid = vm_uuid
         self.fakemac = fakemac
         self._conn_args = {
             "vi": viserver,
@@ -195,9 +205,10 @@ class VirtualBMC(bmc.Bmc):
 
     def get_boot_device(self):
         LOG.debug("Get boot device called for %(vm)s", {"vm": self.vm_name})
+
         try:
             with utils.viserver_open(**self._conn_args) as conn:
-                vm = utils.get_viserver_vm(conn, self.vm_name)
+                vm = _get_vm_object(conn, self)
                 boot_element = vm.config.bootOptions.bootOrder
                 boot_dev = None
                 if boot_element:
@@ -228,7 +239,7 @@ class VirtualBMC(bmc.Bmc):
             return IPMI_INVALID_DATA
         try:
             with utils.viserver_open(**self._conn_args) as conn:
-                vm = utils.get_viserver_vm(conn, self.vm_name)
+                vm = _get_vm_object(conn, self)
                 utils.set_boot_device(conn, vm, device)
         except Exception as e:
             LOG.error(
@@ -241,9 +252,10 @@ class VirtualBMC(bmc.Bmc):
 
     def get_power_state(self):
         LOG.debug("Get power state called for vm %(vm)s", {"vm": self.vm_name})
+
         try:
             with utils.viserver_open(**self._conn_args) as conn:
-                vm = utils.get_viserver_vm(conn, self.vm_name)
+                vm = _get_vm_object(conn, self)
                 if "poweredOn" == vm.runtime.powerState:
                     return POWERON
         except Exception as e:
@@ -260,7 +272,7 @@ class VirtualBMC(bmc.Bmc):
         LOG.debug("Power diag called for vm %(vm)s", {"vm": self.vm_name})
         try:
             with utils.viserver_open(**self._conn_args) as conn:
-                vm = utils.get_viserver_vm(conn, self.vm_name)
+                vm = _get_vm_object(conn, self)
                 utils.send_nmi(conn, vm)
             LOG.debug(
                 "The NMI will be sent to the vm %(vm)s 60 seconds later",
@@ -278,7 +290,7 @@ class VirtualBMC(bmc.Bmc):
         LOG.debug("Power off called for vm %(vm)s", {"vm": self.vm_name})
         try:
             with utils.viserver_open(**self._conn_args) as conn:
-                vm = utils.get_viserver_vm(conn, self.vm_name)
+                vm = _get_vm_object(conn, self)
                 if "poweredOn" == vm.runtime.powerState:
                     vm.PowerOff()
         except Exception as e:
@@ -293,7 +305,7 @@ class VirtualBMC(bmc.Bmc):
         LOG.debug("Power on called for vm %(vm)s", {"vm": self.vm_name})
         try:
             with utils.viserver_open(**self._conn_args) as conn:
-                vm = utils.get_viserver_vm(conn, self.vm_name)
+                vm = _get_vm_object(conn, self)
                 if "poweredOn" != vm.runtime.powerState:
                     vm.PowerOn()
         except Exception as e:
@@ -308,7 +320,7 @@ class VirtualBMC(bmc.Bmc):
         LOG.debug("Soft power off called for vm %(vm)s", {"vm": self.vm_name})
         try:
             with utils.viserver_open(**self._conn_args) as conn:
-                vm = utils.get_viserver_vm(conn, self.vm_name)
+                vm = _get_vm_object(conn, self)
                 if "poweredOn" == vm.runtime.powerState:
                     vm.ShutdownGuest()
         except Exception as e:
@@ -323,7 +335,7 @@ class VirtualBMC(bmc.Bmc):
         LOG.debug("Power reset called for vm %(vm)s", {"vm": self.vm_name})
         try:
             with utils.viserver_open(**self._conn_args) as conn:
-                vm = utils.get_viserver_vm(conn, self.vm_name)
+                vm = _get_vm_object(conn, self)
                 if "poweredOn" == vm.runtime.powerState:
                     vm.Reset()
         except Exception as e:
